==> tap-parser-1.0.1.tgz: package/test/fixtures/indent.js <==
module.exports =
[ [ 'version', '13' ],
  [ 'plan', { start: 1, end: 2 } ],
  [ 'comment', '# nesting\n' ],
  [ 'child',
    [ [ 'plan', { start: 1, end: 2 } ],
      [ 'assert', { ok: true, id: 1, name: 'true is ok' } ],
      [ 'assert', { ok: true, id: 2, name: 'doag is also okay' } ],
      [ 'complete',
        { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ] ],
  [ 'assert', { ok: true, id: 1, name: 'first' } ],
  [ 'child',
    [ [ 'assert', { ok: true, id: 1, name: 'no plan' } ],
      [ 'child',
        [ [ 'plan', { start: 1, end: 3 } ],
          [ 'assert',
            { ok: false, id: 1, skip: 'for no raisin', name: 'granddaughter' } ],
          [ 'assert',
            { ok: true,
              id: 2,
              name: 'grandson',
              diag: { ok: 1, this: 'is not tap', it: 'is yaml' } } ],
          [ 'extra',
            '  ok: 1\n  this: is not tap or yaml\n  it: is garbage\n' ],
          [ 'assert',
            { ok: false, id: 3, todo: true, name: 'grandchild' } ],
          [ 'complete',
            { ok: true,
              count: 3,
              pass: 1,
              fail: 2,
              todo: 1,
              skip: 1,
              plan: { start: 1, end: 3 } } ] ] ],
      [ 'assert', { ok: true, id: 2, name: 'this passes' } ],
      [ 'plan', { start: 1, end: 2 } ],
      [ 'complete',
        { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ] ],
  [ 'assert', { ok: true, id: 2, name: 'second' } ],
  [ 'complete',
    { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ]

==> tap-parser-1.0.4.tgz: package/test/fixtures/indent.js <==
module.exports =
[ [ 'version', '13' ],
  [ 'plan', { start: 1, end: 2 } ],
  [ 'comment', '# nesting\n' ],
  [ 'child',
    [ [ 'plan', { start: 1, end: 2 } ],
      [ 'assert',
        { ok: true, id: 1, time: 1.234, name: 'true is ok' } ],
      [ 'assert',
        { ok: true, id: 2, time: 1.234, name: 'doag is also okay' } ],
      [ 'complete',
        { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ] ],
  [ 'assert', { ok: true, id: 1, time: 2.589, name: 'first' } ],
  [ 'child',
    [ [ 'assert', { ok: true, id: 1, time: 1.001, name: 'no plan' } ],
      [ 'child',
        [ [ 'plan', { start: 1, end: 3 } ],
          [ 'assert',
            { ok: false, id: 1, skip: 'for no raisin', name: 'granddaughter' } ],
          [ 'assert',
            { ok: true,
              id: 2,
              time: 1.001,
              name: 'grandson',
              diag: { ok: 1, this: 'is not tap', it: 'is yaml' } } ],
          [ 'extra',
            '  ok: 1\n  this: is not tap or yaml\n  it: is garbage\n' ],
          [ 'assert',
            { ok: false, id: 3, todo: true, name: 'grandchild' } ],
          [ 'complete',
            { ok: true,
              count: 3,
              pass: 1,
              fail: 2,
              todo: 1,
              skip: 1,
              plan: { start: 1, end: 3 } } ] ] ],
      [ 'assert',
        { ok: true, id: 2, time: 1.2, name: 'this passes' } ],
      [ 'plan', { start: 1, end: 2 } ],
      [ 'complete',
        { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ] ],
  [ 'assert', { ok: true, id: 2, time: 1.2, name: 'second' } ],
  [ 'complete',
    { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ]
